@@ -209,12 +209,14 @@ class Lambda_Client:
         self.s3 = OpenS3Client(cred_path, region)
         self.bucket_name = bucket_name
 
-    def UpdateLambda(self, lambda_name: str, zip_path: str, handler):
+    def UpdateLambda(self, lambda_name: str, zip_path: str, handler: str = ''):
         """
         Updates a AWS Lambda function using the given zip file
 
         :param lambda_name: Name of the Lambda function to be updated
         :param zip_path: Path to the zip file to be uploaded to the function
+        :param handler: Name of the function to be called with the Lambda - should include the module name like you
+        would call it on an imported function ex: lambda_file.handler_func
         :return: The response from Lambda
         """
         key = '{}/{}'.format(lambda_name, os.path.basename(zip_path))
@@ -227,22 +229,22 @@ class Lambda_Client:
             )
         print("Uploaded!")
         print("Updating Lambda Code... ", end='')
-        self.client.update_function_code(
+        response = self.client.update_function_code(
             FunctionName=lambda_name,
             S3Bucket=self.bucket_name,
             S3Key=key,
         )
         print('Updated!')
-
-        print("Updating Lambda Config... ", end='')
-        response = self.client.update_function_code(
-            FunctionName=lambda_name,
-            handler=handler,
-        )
-        print('Updated!')
+        if handler:
+            print("Updating Lambda Config... ", end='')
+            response = self.client.update_function_configuration(
+                FunctionName=lambda_name,
+                Handler=handler,
+            )
+            print('Updated!')
         return response
 
-    def UpdateLambdaFromFolder(self, lambda_name: str, folder_path: str, requirements_path: str = None):
+    def UpdateLambdaFromFolder(self, lambda_name: str, folder_path: str, requirements_path: str = None, handler: str = ''):
         """
         Updates a AWS Lambda function using the given folder
 
@@ -251,6 +253,8 @@ class Lambda_Client:
         :param lambda_name: Name of the Lambda function to be updated
         :param folder_path: Path to the folder to be uploaded to the function
         :param requirements_path: (Optional) Path to requirements that will be installed
+        :param handler: Name of the function to be called with the Lambda - should include the module name like you
+        would call it on an imported function ex: lambda_file.handler_func
         :return: The response from Lambda
         """
         if requirements_path:
@@ -259,5 +263,5 @@ class Lambda_Client:
         print("Zipping folder... ", end='')
         zip_file_path = ZipFolder(folder_path)
         print("Zipped!")
-        response = self.UpdateLambda(lambda_name, zip_file_path)
+        response = self.UpdateLambda(lambda_name, zip_file_path, handler=handler)
         return response
